// background.js (Manifest V3 Service Worker)

// 通知ID と thread_url を紐付けておくためのマップ
const notificationUrlMap = {};

chrome.runtime.onInstalled.addListener(() => {
  console.log("TW8 main_list Checker: background installed");
    chrome.notifications.create("startupNotice", {
    type: "basic",
    iconUrl: "icon.png",
    title: "TW8発言チェッカー",
    message: "インストールされました"
  });
});

chrome.runtime.onStartup.addListener(() => {
  chrome.notifications.create("startupNotice", {
    type: "basic",
    iconUrl: "icon.png",
    title: "TW8発言チェッカー",
    message: "バックグラウンドで稼働中"
  });
});

/**
 * コンテンツスクリプト (content.js) からのメッセージを処理
 */
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  if (message.type === "newRes") {
    // 新着レスの配列が渡される想定
    const newItems = message.items;
    // まとめて通知する
    notifyNewPosts(newItems);

    // 必要なら応答
    sendResponse({ status: "ok" });
    // 非同期で何かする場合は return true; が必要
    return true;
  }
});

/**
 * 複数の新着レスを連続して通知する
 * - 通知クリック時には thread_url に飛ぶ
 */
function notifyNewPosts(items) {
  items.forEach(item => {
    // 通知ID を一意にする（例： "tw8_213092" のように res_id を含める）
    const notifId = `tw8_${item.res_id}`;

    notificationUrlMap[notifId] = item.thread_url;

    chrome.notifications.create(notifId, {
      type: "basic",
      iconUrl: "icon.png",
      title: `${item.character_name} (${item.date})`, // character name
      message: `【${item.subject}】 ${item.content}` // character message
    });
  });
}

/**
 * 通知がクリックされた時に、対応する thread_url を開く
 */
chrome.notifications.onClicked.addListener((notifId) => {
  const url = notificationUrlMap[notifId];
  if (url) {
    chrome.tabs.create({ url });
    chrome.notifications.clear(notifId);
  }
});
